import argparse

from pyfiglet import Figlet
from rich import get_console

from .platform_angular import Angular
from .platform_mvn import Maven
from .platform_python import Python
from .platform_pypi import Pypi
from .version import __version__


def parse_arguments() -> argparse.Namespace:
    parser = argparse.ArgumentParser(description='ondevio-ci')
    parser.add_argument('plataforma', type=str, help='Plataforma para el build (e.g. mvn, npm, python)')
    return parser.parse_args()


def main():
    args = parse_arguments()

    f = Figlet(font='slant')
    print(f.renderText('ondevio-ci'))

    console = get_console()
    console.print(f'Bienvenido a [bold]ondevio-ci v{__version__}[/bold]', highlight=False, style='cyan')
    console.print(f'Para projectos de Python & npm, activar el pyenv y el nvm antes de lanzar este script.',
                  highlight=False, style='cyan')
    console.line(1)

    if args.platform == 'mvn':
        platform_builder = Maven()
        platform_builder.make()
    elif args.platform == 'python':
        platform_builder = Python()
        platform_builder.make()
    elif args.platform == 'pypi':
        platform_builder = Pypi()
        platform_builder.make()
    elif args.platform == 'npm':
        platform_builder = Angular()
        platform_builder.make()
    else:
        console.print('La plataforma no es válida.')


if __name__ == '__main__':
    main()
