from typing import Tuple

from .cli_utils import call
from .cli_utils import get
from .platform_interface import Platform


class Angular(Platform):
    def make(self) -> None:
        with self.console.status("[bold green] Buildeando proyecto de Angular..") as status:
            self.check_for_changes(status)

            # Build with Angular
            status.update(status='Instalando dependencias de npm...')
            call(self.console, 'npm install')
            self.console.log(':white_check_mark: Se han instalado las dependencias.')

            status.update(status='Buildeando aplicación de Angular...')
            call(self.console, f'ng build --configuration production --base-href="{self.project_name}" '
                               f'--outputPath=./build/dist')
            self.console.log(':white_check_mark: Se ha buildeado la aplicación de Angular.')

            self.docker_build(status)
            self.docker_push(status, [self.project_version])
            self.git_push(status)

            status.stop()

        self.print_build_results([self.project_version])

    def get_project_info(self) -> Tuple[str, str]:
        project_name = get('node -e "console.log(require(\'./package.json\').name)"')
        project_version = get('node -e "console.log(require(\'./package.json\').version)"')
        return project_name, project_version
