import os
from typing import Tuple

from .cli_utils import call
from .cli_utils import get
from .platform_interface import Platform


class Pypi(Platform):
    def login_dialog(self) -> None:
        self.username = self.console.input('Escriba su username de [bold]pypi.org[/bold]: ')
        self.password = self.console.input('Escriba su contraseña de [bold]pypi.org[/bold]: ', password=True)

        os.putenv('TWINE_USERNAME', self.username)
        os.putenv('TWINE_PASSWORD', self.password)

    def make(self) -> None:
        with self.console.status("[bold green] Buildeando paquete de pypi:") as status:
            self.check_for_changes(status)

            # Build Python package
            status.update(status='Buildeando paquete de pypi...')
            call(self.console, 'python setup.py sdist bdist_wheel')
            call(self.console, 'twine check dist/*')
            self.console.log(':white_check_mark: Se ha buildeado el paquete.')

            status.update(status='Subiendo a pypi...')
            call(self.console, f'twine upload --non-interactive dist/*')
            self.console.log(':white_check_mark: El paquete ha sido subido a pypi!')

            self.git_push(status)

            status.stop()

        self.print_build_results([self.project_version])

    def print_build_results(self, versions: list):
        self.console.line(1)
        self.console.print('[bold]Proceso de build completo![/bold]', style='bold green')

        for _ in versions:
            self.console.log(f'[bold]Paquete:[/bold] {self.project_name}==={self.project_version}', highlight=False)

    def get_project_info(self) -> Tuple[str, str]:
        project_name = get('python setup.py --name')
        project_version = get('python setup.py --version')
        return project_name, project_version
